==> databutton2-0.4.8.tar.gz: databutton2-0.4.8/databutton/utils/build.py <==
import asyncio
import importlib
import os
import shutil
import sys
from dataclasses import dataclass, field
from pathlib import Path
from typing import List

import databutton as db
import schedule
import yaml
from databutton.decorators.dataframe import DataframeArtifact
from databutton.decorators.schedule import DatabuttonSchedule
from databutton.decorators.streamlit import StreamlitApp
from databutton.helpers import parse
from databutton.utils.kubernetes import generate_manifest
from dataclasses_json import dataclass_json
from fastapi import FastAPI


@dataclass_json
@dataclass
class ArtifactDict:
    streamlit_apps: List[StreamlitApp] = field(default_factory=List)
    dataframes: List[DataframeArtifact] = field(default_factory=List)
    schedules: List[DatabuttonSchedule] = field(default_factory=List)


def load_schedules(artifacts: ArtifactDict):
    for sched in artifacts.schedules:
        mod = importlib.import_module(sched.module_name)
        func = getattr(mod, sched.name)
        schedule.every(sched.seconds).seconds.do(func)

    async def run_continously():
        while True:
            schedule.run_pending()
            await asyncio.sleep(1)

    asyncio.create_task(run_continously())


def load_data_routers_for_app(app: FastAPI, artifacts: ArtifactDict):
    df: DataframeArtifact
    for df in artifacts.dataframes:
        name = df.modulename
        file = df.importfile
        spec = importlib.util.spec_from_file_location(name, file)
        mod = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(mod)
        app.include_router(mod.router)


def generate_artifacts_json():
    # Sort the apps so that the port proxy remains stable
    for i, st in enumerate(sorted(db._streamlit_apps, key=lambda x: x.route)):
        st.port = 8501 + i
    artifacts = ArtifactDict(
        streamlit_apps=[st for st in db._streamlit_apps],
        dataframes=[df for df in db._dataframes],
        schedules=[sched for sched in db._schedules],
    )
    return artifacts


def write_artifacts_json(artifacts: ArtifactDict):
    with open(".databutton/artifacts.json", "w") as f:
        f.write(artifacts.to_json())


def read_artifacts_json() -> ArtifactDict:
    with open(".databutton/artifacts.json", "r") as f:
        return ArtifactDict.from_json(f.read())


def generate_components(rootdir=None):
    sys.path.append(os.curdir)
    sys.path.append(os.curdir + "/.databutton")
    # Find all directive modules and import them
    imports = parse.find_databutton_directive_modules(rootdir=rootdir)

    # Clean the existing artifacts, generate new one
    # TODO: Have a cache mechanism to improve performance
    shutil.rmtree(".databutton", ignore_errors=True)
    os.makedirs(".databutton")
    decorator_modules = {}
    for name in imports:
        decorator_modules[name] = importlib.import_module(name)

    # Write the artifacts
    # Sort the apps so that the port proxy remains stable
    artifacts = generate_artifacts_json()
    write_artifacts_json(artifacts)

    # Copy the Dockerfile
    dir_path = os.path.dirname(os.path.realpath(__file__))
    shutil.copytree(os.path.join(dir_path, "../docker"), ".databutton/docker")

    # Generate a kubernetes manifest
    manifest = generate_manifest(artifacts)
    kube_path = ".databutton/kubernetes"
    Path(kube_path).mkdir(exist_ok=True, parents=True)
    for kind, d in manifest.items():
        with open(os.path.join(kube_path, f"{kind}.yaml"), "w") as f:
            yaml.safe_dump(d, f, allow_unicode=True)
    return artifacts

==> databutton2-0.6.27.tar.gz: databutton2-0.6.27/databutton/utils/build.py <==
import asyncio
import importlib
import os
import shutil
import sys
from dataclasses import dataclass, field
from pathlib import Path
from typing import List

import schedule
import yaml
from dataclasses_json import dataclass_json
from fastapi import FastAPI

import databutton as db
from databutton.decorators.dataframe import DataframeArtifact
from databutton.decorators.schedule import DatabuttonSchedule
from databutton.decorators.streamlit import StreamlitApp
from databutton.helpers import parse
from databutton.utils.kubernetes import generate_manifest
from databutton.version import __version__


@dataclass_json
@dataclass
class ArtifactDict:
    streamlit_apps: List[StreamlitApp] = field(default_factory=List)
    dataframes: List[DataframeArtifact] = field(default_factory=List)
    schedules: List[DatabuttonSchedule] = field(default_factory=List)


def load_schedules(artifacts: ArtifactDict):
    for sched in artifacts.schedules:
        mod = importlib.import_module(sched.module_name)
        func = getattr(mod, sched.func_name)
        schedule.every(sched.seconds).seconds.do(func)

    async def run_continously():
        while True:
            schedule.run_pending()
            await asyncio.sleep(1)

    asyncio.create_task(run_continously())


def load_data_routers_for_app(app: FastAPI, artifacts: ArtifactDict):
    df: DataframeArtifact
    for df in artifacts.dataframes:
        name = df.modulename
        file = df.importfile
        spec = importlib.util.spec_from_file_location(name, file)
        mod = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(mod)
        app.include_router(mod.router)


def generate_artifacts_json():
    # Sort the apps so that the port proxy remains stable
    for i, st in enumerate(sorted(db._streamlit_apps, key=lambda x: x.route)):
        st.port = 8501 + i
    artifacts = ArtifactDict(
        streamlit_apps=[st for st in db._streamlit_apps],
        dataframes=[df for df in db._dataframes],
        schedules=[sched for sched in db._schedules],
    )
    return artifacts


def write_artifacts_json(artifacts: ArtifactDict):
    with open(".databutton/artifacts.json", "w") as f:
        f.write(artifacts.to_json())


def read_artifacts_json() -> ArtifactDict:
    with open(".databutton/artifacts.json", "r") as f:
        return ArtifactDict.from_json(f.read())


def generate_components(rootdir=os.curdir):
    sys.path.append(os.curdir)
    sys.path.append(os.curdir + "/.databutton")
    # Find all directive modules and import them
    imports = parse.find_databutton_directive_modules(rootdir=rootdir)

    # Clean the existing artifacts, generate new one
    # TODO: Have a cache mechanism to improve performance
    shutil.rmtree(".databutton", ignore_errors=True)
    os.makedirs(".databutton")
    decorator_modules = {}
    for name in imports:
        decorator_modules[name] = importlib.import_module(name)

    # Write the artifacts
    # Sort the apps so that the port proxy remains stable
    artifacts = generate_artifacts_json()
    write_artifacts_json(artifacts)

    # Copy the Dockerfile
    dir_path = os.path.dirname(os.path.realpath(__file__))
    os.mkdir(".databutton/docker")
    dockerfile_path = os.path.join(dir_path, "../docker/Dockerfile")
    dest_dockerfile_path = ".databutton/docker/Dockerfile"
    with open(dockerfile_path, "r") as original:
        contents = original.read()
        with open(dest_dockerfile_path, "w") as dest:
            dest.write(
                # Overwrite image
                contents.replace("REPLACE_ME_VERSION", __version__)
            )

    # Generate a kubernetes manifest
    manifest = generate_manifest(artifacts)
    kube_path = ".databutton/kubernetes"
    Path(kube_path).mkdir(exist_ok=True, parents=True)
    for kind, d in manifest.items():
        with open(os.path.join(kube_path, f"{kind}.yaml"), "w") as f:
            yaml.safe_dump(d, f, allow_unicode=True)
    return artifacts
